@@ -3,6 +3,9 @@
   library.dynam("cluster", pkg, lib)
 }
 
+## no S4 methodology here; speedup :
+.noGenerics <- TRUE
+
 ## for R versions < 1.7:
 if(paste(R.version$major, R.version$minor, sep=".") < 1.7) {
 
